%generates the cov matrix for the static model case; p and q are fixed
function [SY,V] = getcvfix(y,p,q)
    
    ess=mean((y-mean(y)).^2);
    et=y-mean(y);
    T = length(et);

    %calculate different derivatives of f_t'/f_t 
    sg   = 1/sqrt(ess);
    eg   = et*sg;
    d10t = sg*eg;                                 %w.r.t the constant term (order (1,0))
    d20t = (sg^2)*(eg.^2-1);                      %w.r.t the constant term (order (2,0))
    
    d30t = (sg^3)*(eg.^3-3*eg);                   %w.r.t the constant term (order (3,0))
    d40t = (sg^4)*(eg.^4-6*eg.^2+3);              %w.r.t the constant term (order (4,0))

    d01t = d20t/2;          %w.r.t the constant and variance terms (order (0,1)).

    
    %calculate the information matrix
    IM(1,1) = mean(d10t.*d10t);
    IM(1,2) = mean(d10t.*d01t);
    IM(2,1) = IM(1,2);
    IM(2,2) = mean(d01t.*d01t);
    FM      = IM^-1;      %inverse of information matrix
    
    AY = zeros(3,T);
    SY=zeros(3,1);
    

    xi0 = (1-q)/(2-p-q); 
        
    %calculate the first order derivative of \xi_t (1,0) and (0,1)
    xid10t = zeros(T,1);
        
    for i2=2:T
         xid10t(i2) = (p+q-1)*xid10t(i2-1)+d10t(i2-1);
    end
    xid10t = xi0*(1-xi0)*(p+q-1)*xid10t;
        
        
    A = zeros(T,1);
    for i3 = 1:T
        A(i3,1) = 1*(1-xi0)/xi0*d20t(i3) ... 
                +1/(xi0^2)*(d10t(i3)*xid10t(i3)+d10t(i3)*xid10t(i3));
             
    end
        
    D2   = zeros(2,1);
    phi2 = zeros(2,1);
    for i4 = 1:1
            D2(1,i4)   = mean(d10t.*A(:,i4));
            D2(2,i4)   = mean(d01t.*A(:,i4));
            phi2(:,i4) = -FM*D2(:,i4);
    end
        
    J2 = zeros(T,1);
    for i5 = 1:T
            for i6 = 1:1
                %J2(i5,i6) = [d10t(i5) bd1t(i5) d01t(i5)]*phi2(:,i6);
                J2(i5,i6) = [d10t(i5) d01t(i5)]*phi2(:,i6);
            end
    end
        
    L2 = (A+J2)';
    LL2 = (A);
        
    B    = -(1-xi0)*(1-2*xi0)/(xi0^2)*d30t;
    D3   = zeros(2,1);
    phi3 = zeros(2,1);
    for i4 = 1:1
            D3(1,i4)   = mean(d10t.*B(:,i4));
            D3(2,i4)   = mean(d01t.*B(:,i4));
            phi3(:,i4) = -FM*D3(:,i4);
    end
        
    J3 = zeros(T,1);
    for i5 = 1:T
            for i6 = 1:1
               J3(i5,i6) = [d10t(i5) d01t(i5)]*phi3(:,i6);
            end
    end
        
    L3 = (1/(T^0.25))*(B+J3)';
    LL3 = (1/(T^0.25))*(B)';
        
    % calculate 4th order terms
    C = ((1-xi0)*(1+((1-xi0)/xi0)^3)-3*(1-xi0)^2/(xi0^2))*d40t;
    D4   = zeros(2,1);
    phi4 = zeros(2,1);
        for i4 = 1:1
            D4(1,i4)   = mean(d10t.*C(:,i4));
            
            D4(2,i4)   = mean(d01t.*C(:,i4));
            phi4(:,i4) = -FM*D4(:,i4);
        end
        
   J4 = zeros(T,1);
        for i5 = 1:T
            for i6 = 1:1
                
                J4(i5,i6) = [d10t(i5) d01t(i5)]*phi4(:,i6);
            end
        end
        
    L4 = (1/(T^0.5))*(C+J4)';
    LL4 = (1/(T^0.5))*(C)';
    
   
    AY(1,:) = L2; 
    AY(2,:) = L3;
    AY(3,:) = L4;
    
    SY=(T^(-0.5))*sum(LL2);       
    SY(2)=(T^(-0.5))*sum(LL3);   
    SY(3)=(T^(-0.5))*sum(LL4);
   
    
    V = zeros(3,3); 
    for c1 = 1:3
        for c2 = 1:3
           V(c1,c2) = mean(AY(c1,:).*AY(c2,:));
        end
    end
 
   
end