function [est, loglik] = lik_pqfixe(y,x,lp,up,lq,uq,trm)

    in1 = unifrnd(-4,0);
    in2 = unifrnd(0,4);
    in3 = unifrnd(-1,1);
    in4 = unifrnd(0.25,3);
    in5 = unifrnd(lp,up);
    in6 = unifrnd(lq,uq);
    start_point = [in1,in2,in3,in4,in5,in6];
    model = @lik_model;
    
    lb = [-4, 0,  -1, 0.1, lp, lq];
    ub = [0,  4,  1,  3,    up, uq];
    
    AA = [0 0 0 0 -1 -1];
    BB = -(1+trm);
    
    options  =  optimset('fmincon');
    options  =  optimset(options , 'Algorithm ','interior-point');
    options  =  optimset(options, 'Hessian','bfgs');
    options  =  optimset(options , 'TolFun'      , 1e-006);
    options  =  optimset(options , 'TolX'        , 1e-006);
    options  =  optimset(options , 'TolCon'      , 1e-006);
    options  =  optimset(options , 'Display'     , 'off');
    options  =  optimset(options , 'Diagnostics' , 'off');
    options  =  optimset(options , 'LargeScale'  , 'off');
    options  =  optimset(options , 'MaxIter'     , 1500);
    options  =  optimset(options , 'Jacobian'     ,'off');
    options  =  optimset(options , 'MeritFunction'     ,'multiobj');
    options  =  optimset(options , 'MaxFunEvals' , 3000);
    [est,nlik] = fmincon(model, start_point, AA, BB, [] ,[],lb, ub, [], options);
    loglik = -nlik;
    
    function nln = lik_model(pms)
        beta11 = pms(1);
        beta12 = pms(2);
        beta2  = pms(3);
        sigma2 = pms(4);
        p      = pms(5);
        q      = pms(6);
        n = length(y);
        nln = 0;
        PRL = zeros(n,1);
        PR = zeros(n,1);
        for i=1:n
            if i==1
                PR(i) = (1-q)/(2-p-q);
            else
                PR(i) = p*PRL(i-1)+(1-q)*(1-PRL(i-1));
            end
            PRL(i) = (exp(-(y(i)-beta11*x(i,1)-beta2*x(i,2))^2/(2*sigma2))*PR(i))/(exp(-(y(i)-beta11*x(i,1)-beta2*x(i,2))^2/(2*sigma2))*PR(i)+exp(-(y(i)-beta12*x(i,1)-beta2*x(i,2))^2/(2*sigma2))*(1-PR(i)));
            nln = nln-log(PR(i)*sigma2^(-0.5)*exp((-(y(i)-beta11*x(i,1)-beta2*x(i,2))^2)/(2*sigma2))+(1-PR(i))*sigma2^(-0.5)*exp((-(y(i)-beta12*x(i,1)-beta2*x(i,2))^2)/(2*sigma2)));
        end
        
    end
end