% The static model
% Results are used to generate Table 1

clear; clc; close all;

%% DGP
T  = 500; % sample size
qstar=0.2; %transition probability; set to 0.2,0.4,0.6,0.8.
cc=0;  %set to 0 for distribution under the null; 
        %to 7.3,6.4,4.7,3.0 for distributions under alternatives 

%% You should not need to modify the following
pstar=0.9;
phi=0.0; %AR coefficient
vs = 1; % the variance
mu0=0; % the mean for regime 1
mu1=mu0+cc*(T^(-1/4));% the mean for regime 2
chg=mu1-mu0;

%% Preparation 
rng(0);
tol=1e-5;  %tolerance level for zero
iter = 10000; %replication
YY=zeros(1,iter);
AY=YY;
AY2=YY;
mx=YY;  %LR finite sample
suplr=YY; %LR approximation

chp=mx; %CHP finite sample
suplr3=YY; %CHP approximation
suplr4=YY; %QLR finite sample
lrcw=mx;   %QLR approximation

vsave=zeros(3,3);
smallv=0;

%% simulation
parfor ci = 1:iter
    if abs(cc)<1e-10
    [y,x]= RS_dgp(mu0, phi, vs, T, 'CA');
    else
    [y,x]= RS_dgpA(mu0, mu1, phi, vs, pstar, qstar, T);
    end
    x=ones(length(y),1); %static model
    
    % estimation under H_0
    [est0, lik_0] = lik_null(y,x); 
    
    %estimation under H_1
    mx(ci) = lik_pqvars(y,x,[pstar,qstar],lik_0); %LR 
    lrcw(ci)=  lik_cws(y,x,[pstar,qstar],lik_0); %QLR 
    [test,~] = funcTSm(y,x,pstar+qstar-1,pstar+qstar-1,tol);
    chp(ci)=2*test; %CHP 
    
    %obtain approximations
     [sytemp,V] = getcvfix(y,pstar,qstar); %get covariance matrix
     sy0 = getnormal(V,y,chg,pstar,qstar); %sample from multivariate normal
     
     %approximation to LR: all terms enter
     [suplr(ci),~] = opt(sy0,V);
     
     %approximation to QLR
     sycw=sy0;
     vcw=V;
     sycw(1)=0;
     vcw(1,1)=0;
     [suplr4(ci),~] = opt(sycw,vcw);
     
    
    %approximation to CHP
     syr=sy0*0;
     syr(1)=sy0(1);
     vr=V*0;
     vr(1,1)=V(1,1);
     
     [suplr3(ci),tlr] = opt(syr,vr);

     [suplr3(ci),chp(ci), suplr(ci), mx(ci),suplr4(ci),lrcw(ci)]
     
end
z=[suplr3',chp',suplr',mx',suplr4',lrcw'];

z=sort(z);

%% plot cdfs
ecdf(suplr);
hold on;
ecdf(mx);
hold on;
ecdf(suplr3);
hold on;
ecdf(chp);
hold on;
ecdf(lrcw);
hold on;
ecdf(suplr4);
hold off;

%% save results, used to generate Table 1
myfile = ['power_q' num2str(qstar) '_c' num2str(cc) '_s.mat'];
save(myfile,'z');
%columns of myfile: (1) CHP approximation, (2) CHP finite sample, (3)LR approximation, (4) LR
%finite sample, (5)QLR approximation, (6) QLR finite sample.
