%Replication file for Table 2
%This code is structured for a cluster of multiple nodes. See the readme
%file for how to run this code.
%It has been tested on Matlab 2017b and 2013a.
%If run on a desktop, then remove "function FiniteSample(ntime, task)",
%and set ntime=5000 and task=1. Also replace "for" with "parfor" to utilize multiple cores.

function FiniteSample(ntime, task)

T  = 500; %sample size
eps = 0.02;%trimming parameter, 0.02 or 0.05.

% DGP parameters y_t=b1+b2*y_(t-1)+e_t
b1 = 0.0;
b2 = 0.5;
s2 = 1.0; %variance of e_t

%time keeping
tic

ss=round(eps*100);
%create the matrix for (p,q)
indx = 1;
for i=ss:2:(100-ss)
    for j=i:2:(100-ss)
        pi = i/100;
        qi = j/100;
        if (pi+qi)>=(1+eps)
            PQ(indx,1) = pi;
            PQ(indx,2) = qi;
            indx = indx+1;
        end
    end
end

% range of task is [1,ntasks]
ibegin = (task-1)*ntime + 1;
iend = task*ntime;

%save the test and cutoff values
LRt = zeros(ntime,6);

%number of simulations to produce the cvs
nrep=200;

for i=ibegin:iend
   
    rng(task*10000+i); % DGP; set seed to run on multiple nodes
    [y,x]= RS_dgp( b1, b2, s2, T, 'CA');
    
    %estimate the model under H_0
    [est0, lik_0] = lik_null(y,x);
    
    %simulation using the null estimates
    cv=getcv(y,x,est0,PQ,nrep);
    
    mx = lik_pqvar(y,x,PQ,lik_0);
    [mx,cv]
    LRt(i-ibegin+1,:) = [mx,cv];
end
myfile = ['AR1_size_values.' num2str(task) '.mat'];
save(myfile,'LRt');

rejf=zeros(5,1);
rejf(1)=sum(LRt(:,1)>LRt(:,2));
rejf(2)=sum(LRt(:,1)>LRt(:,3));
rejf(3)=sum(LRt(:,1)>LRt(:,4));
rejf(4)=sum(LRt(:,1)>LRt(:,5));
rejf(5)=sum(LRt(:,1)>LRt(:,6));

myfile = ['AR1_size_rejf.' num2str(task) '.mat'];
save(myfile,'rejf');

toc
%matlabpool close
end
