%Replication file for Table 3
%This code is structured to run on a cluster using multiple nodes.
%It has been tested on Matlab 2017b and 2013a.
%If run on a desktop, then comment out "function FiniteSample(ntime, task)",
%and set ntime=5000 and task=1. 
%Also, replace "for" with "parfor" to utilize multiple cores.

function FiniteSampleA(ntime, task)

T  = 500; %sample size
eps = 0.02;%trimming parameter

% DGP parameters
mu0 = -0.6;
mu1 = 0.6;

pi  = 0.90;
qi  = 0.90;

phi = 0.50;
variance = 1; %variance of e_t

%time keeping
tic

ss=round(eps*100);
%create the matrix for (p,q)
indx = 1;
for i=ss:2:(100-ss)
    for j=i:2:(100-ss)
        p = i/100;
        q = j/100;
        if (p+q)>=(1+eps)
            PQ(indx,1) = p;
            PQ(indx,2) = q;
            indx = indx+1;
        end
    end
end

% range of task is [1,ntasks]
ibegin = (task-1)*ntime + 1;
iend = task*ntime;

%save the test and cutoff values
LRt = zeros(ntime,6);

%number of simulations to produce the cvs
nrep=200;

for i=ibegin:iend
   
    rng(task*10000+i); % DGP; set seed to run on multiple nodes
    [y,x] = RS_dgpA(mu0, mu1, phi, variance, pi, qi, T);
    
    %estimate the model under H_0
    [est0, lik_0] = lik_null(y,x);
    
    %simulation using the null estimates
    cv=getcv(y,x,est0,PQ,nrep);
    
    mx = lik_pqvar(y,x,PQ,lik_0);
    [mx,cv]
    LRt(i-ibegin+1,:) = [mx,cv];
end
myfile = ['AR1_power_values.' num2str(task) '.mat'];
save(myfile,'LRt');

rejf=zeros(5,1);
   
rejf(1)=sum(LRt(:,1)>LRt(:,2)); %90
rejf(2)=sum(LRt(:,1)>LRt(:,3)); %92.5
rejf(3)=sum(LRt(:,1)>LRt(:,4)); %95
rejf(4)=sum(LRt(:,1)>LRt(:,5)); %97.5
rejf(5)=sum(LRt(:,1)>LRt(:,6)); %99

myfile = ['AR1_power_rejf.' num2str(task) '.mat'];
save(myfile,'rejf');

toc
%matlabpool close
end
