
%clear; close all; clc

%% load data
    load GDP;
    D=GDP;%full sample
    %D=GDP(1:187,:);% subsample, up to 2006
 
%% trimming parameters and number of simulation replications
    trm=0.02;
    nrep=5000;
    
%%  Preparation
    
    y = D(:,1);
    T = size(y,1);
    x = ones(T,2);
    x(:,2) = D(:,2);    
    
    lp = trm;
    up = 1-trm;
    lq = trm;
    uq = 1-trm;
    L=trm;%0.05;0.02;
    U=1-2*trm;%0.90;0.96;
    tol=1e-5; %tol for zero; 
    rng(12345);
    
    parpool (10);
    tic
%% The SupLR test

    %estimation under H_0
    [est0, loglik0] = lik_null(y,x);
    
    % estimation under H_1; use multiple initial values
    %mx=-1e6;
    tlr=zeros(16,1);
    estr=zeros(16,6);
    parfor ct = 1:16
        [est11, loglik1] = lik_pqfixe(y,x,lp,up,lq,uq,trm);
        tlr(ct) = 2*(loglik1-loglik0);
        estr(ct,:)=est11;
    end
    [mx,ind]=max(tlr);
    est1=estr(ind,:);
   
    %critical values for the SupLR test   
    indx = 1;
    for i=2:2:98
        for j=i:2:98
            pi = i/100;
            qi = j/100;
            if (pi+qi)>=(1+eps)
                PQ(indx,1) = pi;
                PQ(indx,2) = qi;
                indx = indx+1;
            end
        end
    end

    count = size(PQ,1);
    V = re(y, x,est0, PQ);
    [A,S,~] = svd(V);
    slr=zeros(nrep-1,1);
    
    parfor simu=1:(nrep-1)
        u = randn(3*count,1);
        L234 = (A*sqrt(S)*u);
        [lr,~] = opt(L234,V);
        slr(simu)=lr;
    end
    
    disp ('The SupLR test (2% trimming):');
    disp (mx);
    disp ('The critical values of the SupLR test (10%--7.5%--5%--2.5%--1%):');
    slr=sort(slr);
    cvs=[slr(ceil(nrep*0.90)),slr(ceil(nrep*0.925)),slr(ceil(nrep*0.95)),slr(ceil(nrep*0.975)),slr(ceil(nrep*0.99))];
    disp (cvs);
    disp ('The p-value of the SupLR test:');
    pval=sum(mx<slr)/nrep;
    disp (pval);
    disp ('Estimates under the null hypothesis (intercept, AR(1) coefficient, residual variance):');
    disp (est0);
    disp ('Estimates under the alternative hypothesis (mu1,mu2, AR(1) coefficient, residual variance, p,q):');
    disp (est1);
    SupLR_result=[mx,cvs,pval];
 %% The SupTS test of CHP
 
    [test,~] = funcTSm(y,x,L,U,tol);
    b0 = regress(y,x);
    u  = y-x*b0; 
    v0 = std(u,1);
    estc = [b0;v0];
    cvc=cvchp(y,estc,L, U, nrep, tol);
    
    disp ('The SupTS test of CHP (2% trimming):');
    disp (test);
    disp ('The critical values of the SupTS test (10%--7.5%--5%--2.5%--1%):')
    disp (cvc);
    SupTS_result=[test,cvc];
    
  %% The QLR test of CW 
    %lp=0;
    %up=1;
    lr=zeros(16,1);
    parfor ct = 1:16  %optimization with different initial values
           [~, lik_a] = lik_pqcwe(y,x,0.5,1);
           lr(ct) = 2*(lik_a-loglik0);
           
    end
    cw=max(lr);
    cvb=cvcw(y,x,0.5,1,nrep);
    disp ('The QLR test CW:');
    disp (cw);
    disp ('the critical values of the QLR test (5%):');
    disp ('    5.61');
    disp ('the bootstrapped critical values of the QLR test (10%--7.5%--5%--2.5%--1%):');
    disp (cvb);
    QLR_result=[cw,5.61,cvb];
    toc
    
    myfile = 'GDP_1960_2014.mat';
    save (myfile,'SupLR_result','est0','est1','SupTS_result','QLR_result');
    delete(gcp('nocreate'));  
  
